﻿using System;
using System.Linq;
using System.Windows;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.RichTextBoxUI.Dialogs;
using Telerik.Windows.Documents.UI.Extensibility;

namespace CustomInsertTableDialog
{
    [CustomInsertTableDialogAttribute]
    public partial class MyInsertTableDialog : RadRichTextBoxWindow, IInsertTableDialog
    {
        private Action<int, int> insertTableCallback;

        public MyInsertTableDialog()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Shows the dialog. Specified insert table callback is applied on user confirmation.
        /// </summary>
        /// <param name="insertTableCallback">The insert table callback. First parameter specifies rows; second parameter specifies columns.</param>
        public void ShowDialog(Action<int, int> insertTableCallback)
        {
            this.ShowDialogInternal(insertTableCallback, null);
        }

        private void ShowDialogInternal(Action<int, int> insertTableCallback, RadRichTextBox owner)
        {
            this.insertTableCallback = insertTableCallback;
            this.SetOwner(owner);
            this.ShowDialog();
        }

        private void buttonOK_Click(object sender, RoutedEventArgs e)
        {
            if (!radNumRows.Value.HasValue)
            {
                this.ShowAlert((int)radNumRows.Minimum, (int)radNumRows.Maximum);
                return;
            }

            int rows = (int)radNumRows.Value.Value;

            if (!radNumColumns.Value.HasValue)
            {
                this.ShowAlert((int)radNumColumns.Minimum, (int)radNumColumns.Maximum);
                return;
            }

            int columns = (int)radNumColumns.Value.Value;

            this.insertTableCallback(rows, columns);
            this.Close();
        }

        private void ShowAlert(int minValue, int maxValue)
        {
            string message = string.Format(LocalizationManager.GetString("Documents_InsertTableDialog_NumberMustBeBetween"), minValue, maxValue);
            RadWindow.Alert(new DialogParameters() { Header = this.Header, Content = message });
        }

        private void buttonCancel_Click(object sender, RoutedEventArgs e)
        {
            this.Close();
        }

        protected override void OnClosed(WindowClosedEventArgs args)
        {
            base.OnClosed(args);

            this.insertTableCallback = null;
            this.Owner = null;
        }
    }
}

